@@ -3,11 +3,11 @@ package DateTime::Format::Strptime;
 use strict;
 use warnings;
 
-our $VERSION = '1.77';
+our $VERSION = '1.78';
 
 use Carp qw( carp croak );
 use DateTime 1.00;
-use DateTime::Locale 1.23;
+use DateTime::Locale 1.30;
 use DateTime::Format::Strptime::Types;
 use DateTime::TimeZone 2.09;
 use Exporter ();
@@ -978,7 +978,7 @@ DateTime::Format::Strptime - Parse and format strp and strf time patterns
 
 =head1 VERSION
 
-version 1.77
+version 1.78
 
 =head1 SYNOPSIS
 
@@ -1175,6 +1175,12 @@ the full name.
 
 The datetime format according to the given locale.
 
+Note that this format can change without warning in new versions of
+L<DateTime::Locale>. You should not use this pattern unless the string you are
+parsing was generated by using this pattern with L<DateTime> B<and> you are
+sure that this string was generated with the same version of
+L<DateTime::Locale> that the parser is using.
+
 =item * %C
 
 The century number (0-99).
@@ -1282,10 +1288,22 @@ Monday of January is the first day of week 1.
 
 The date format according to the given locale.
 
+Note that this format can change without warning in new versions of
+L<DateTime::Locale>. You should not use this pattern unless the string you are
+parsing was generated by using this pattern with L<DateTime> B<and> you are
+sure that this string was generated with the same version of
+L<DateTime::Locale> that the parser is using.
+
 =item * %X
 
 The time format according to the given locale.
 
+Note that this format can change without warning in new versions of
+L<DateTime::Locale>. You should not use this pattern unless the string you are
+parsing was generated by using this pattern with L<DateTime> B<and> you are
+sure that this string was generated with the same version of
+L<DateTime::Locale> that the parser is using.
+
 =item * %y
 
 The year within century (0-99). When a century is not otherwise specified
@@ -1360,7 +1378,7 @@ software much more, unless I get so many donations that I can consider working
 on free software full time (let's all have a chuckle at that together).
 
 To donate, log into PayPal and send money to autarch@urth.org, or use the
-button at L<http://www.urth.org/~autarch/fs-donation.html>.
+button at L<https://www.urth.org/fs-donation.html>.
 
 =head1 AUTHORS
 
